<?php
namespace Teknisa\PLA\Modules\Ciclo\Services;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class Pla10100ElaboracaoCicloService {

    public function __construct($dataSourceManager, $entityManager, $environment) {
        $this->dataSourceManager = $dataSourceManager;
        $this->entityManager = $entityManager;
        $this->environment = $environment;
    }
    
    public function callProcedureAtualizaCardapio($row) {
        $connection = $this->entityManager->getConnection();
        $procedure = new StoredProcedure($connection, 'CRIACARD_CICLO');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $row['CDFILIAL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDSERVFILI', Param::PARAM_INPUT, $row['CDSERVFILI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTMESCARD', Param::PARAM_INPUT, $row['DTINICICLO'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $row['CDOPERADOR'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDEXCLUIRCARD', Param::PARAM_INPUT, 'S', Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRLOGCARDCICLO', Param::PARAM_INPUT, $row['NRLOGCARDCICLO'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPADCICLO', Param::PARAM_INPUT, $row['CDPADCICLO'], Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
    public function deletePrato($row) {
        $query = "DELETE FROM
                    COMPCARDCICLO
                WHERE 
                    CDCARDCICLO = :CDCARDCICLO AND
                    CDPADCICLO = :CDPADCICLO AND
                    NRCARDCICLO = :NRCARDCICLO AND
                    NRSEQCARDCICLO = :NRSEQCARDCICLO AND
                    CDTIPOPRAT = :CDTIPOPRAT";
        $params = array(
            "CDCARDCICLO" => $row["CDCARDCICLO"],
            "CDPADCICLO" => $row["CDPADCICLO"],
            "NRCARDCICLO" => $row["NRCARDCICLO"],
            "NRSEQCARDCICLO" => $row["NRSEQCARDCICLO"],
            "CDTIPOPRAT" => $row["CDTIPOPRAT"]
        );
        $sql = $this->entityManager->getConnection()->prepare($query);
        $sql->execute($params);
    }
    
    public function deletePratoPeriodo($row) {
        $query = "DELETE FROM
                    COMPCARDCICLO
                WHERE 
                    CDCARDCICLO = :CDCARDCICLO AND
                    CDPADCICLO = :CDPADCICLO AND
                    NRCARDCICLO BETWEEN :NRCARDCICLOINI AND :NRCARDCICLOFIN";
        $params = array(
            "CDCARDCICLO" => $row["CDCARDCICLO"],
            "CDPADCICLO" => $row["CDPADCICLO"],
            "NRCARDCICLOINI" => $row["NRCARDCICLOINI"],
            "NRCARDCICLOFIN" => $row["NRCARDCICLOFIN"]
        );
        $sql = $this->entityManager->getConnection()->prepare($query);
        $sql->execute($params);
    }
    
    public function getAllFilialOperador($conditions) {
        $filterCriteria = new FilterCriteria('filial_filioper', $conditions);
		return $this->dataSourceManager->findBy($filterCriteria)->getRows();
    }
    
    public function getCardaDiaCiclo($row) {
        $query = "SELECT
                    LPAD(TO_CHAR(NRCARDCICLO),3,'0') AS NRCARDCICLO,
                    NRDIASEMCICLO
                FROM
                    CARDADIACICLO
                WHERE
                    CDCARDCICLO = :CDCARDCICLO AND
                    CDPADCICLO = :CDPADCICLO";
        $params = array(
            "CDCARDCICLO" => $row["CDCARDCICLO"],
            "CDPADCICLO" => $row["CDPADCICLO"]
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function getCnfCardCiclo($row) {
        $query = "SELECT
                    CC.CDCARDCICLO,
                    CC.CDPADCICLO,
                    CC.NRSEQCNFCICLO,
                    CC.CDTIPOPRAT,
                    TP.NMTIPOPRAT,
                    CC.DSCOMPTPCICLO,
                    CC.IDOPCARDCICLO,
                    CC.NRORDCNFCICLO
                FROM
                    CNFCARDCICLO CC JOIN TIPOPRAT TP ON CC.CDTIPOPRAT = TP.CDTIPOPRAT
                WHERE
                    CDCARDCICLO = :CDCARDCICLO AND
                    CDPADCICLO = :CDPADCICLO
                ORDER BY
                    NRORDCNFCICLO";
        $params = array(
            "CDCARDCICLO" => $row["CDCARDCICLO"],
            "CDPADCICLO" => $row["CDPADCICLO"]
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function getDataCardapioCiclo($row) {
        $query = "SELECT
                    *
                FROM
                    (
                        SELECT
                            CA.DTCARDAPIO,
                            DECODE(
                                TO_CHAR(
                                    CA.DTCARDAPIO,
                                    'D'
                                ),
                                '1',
                                'dom',
                                '2',
                                'seg',
                                '3',
                                'ter',
                                '4',
                                'qua',
                                '5',
                                'qui',
                                '6',
                                'sex',
                                '7',
                                'sab'
                            ) DIASEMCARD,
                            ( TO_NUMBER(TO_CHAR(
                                CA.DTCARDAPIO,
                                'DD'
                            ) ) - TO_NUMBER(TO_CHAR(
                                TO_DATE(:DTINI),
                                'DD'
                            ) ) ) AS ORD
                        FROM
                            CARDADIA CA
                        WHERE
                                CA.CDFILIAL =:CDFILIAL
                            AND
                                CA.CDSERVFILI =:CDSERVFILI
                            AND
                                CA.DTCARDAPIO BETWEEN :DTINI AND :DTFIN
                        ORDER BY CA.DTCARDAPIO
                    ) CARD
                    INNER JOIN (
                        SELECT
                            ( LPAD(
                                NRCARDCICLO,
                                3,
                                '0'
                            ) ) AS NRCARDCICLO,
                            DECODE(
                                NRDIASEMCICLO,
                                '1',
                                'dom',
                                '2',
                                'seg',
                                '3',
                                'ter',
                                '4',
                                'qua',
                                '5',
                                'qui',
                                '6',
                                'sex',
                                '7',
                                'sab'
                            ) AS NRDIASEMCICLO,
                            TO_NUMBER(NRCARDCICLO) - TO_NUMBER(:NRCARDCICLOINI) AS ORD
                        FROM
                            CARDADIACICLO
                        WHERE
                            (
                                CDCARDCICLO =:CDCARDCICLO
                            ) AND (
                                CDPADCICLO =:CDPADCICLO
                            ) AND (
                                NRCARDCICLO BETWEEN :NRCARDCICLOINI AND :NRCARDCICLOFIN
                            )
                    ) CICLO ON CICLO.ORD = CARD.ORD
                ORDER BY CARD.ORD";
        $params = array(
            "DTINI" => $row['DTCARDAPIO']['start'],
            "CDCARDCICLO" => $row['CDCARDCICLO'],
            "NRCARDCICLOINI" => $row['NRCARDCICLOINI'],
            "NRCARDCICLOFIN" => $row['NRCARDCICLOFIN'],
            "CDSERVFILI" => $row['CDSERVFILI'],
            "CDPADCICLO" => $row['CDPADCICLO'],
            "CDFILIAL" => $row['CDFILIAL'],
            "DTFIN" => $row['DTCARDAPIO']['end']
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function getLogErrors($row) {
        $query = "SELECT
                    NRLOGCARDCICLO
                FROM
                    LOGCARDCICLO
                WHERE
                    CDFILIAL = :CDFILIAL AND
                    NRLOGCARDCICLO = :NRLOGCARDCICLO AND
                    IDLOGCARDCICLO <> '3'";
        $params = array(
            "CDFILIAL" => $row["CDFILIAL"],
            "NRLOGCARDCICLO" => $row["NRLOGCARDCICLO"]
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function getNrLogCardCiclo($row) {
        $query = "SELECT
                    NVL(MAX(NRLOGCARDCICLO), 0) AS NRLOGCARDCICLO
                FROM
                    LOGCARDCICLO
                WHERE
                    CDFILIAL = :CDFILIAL";
        $params = array(
            "CDFILIAL" => $row["CDFILIAL"]
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function getPadraoCicloServicoPorUnidade($row) {
        $query = "SELECT
                    MAX(CDPADCICLO) AS CDPADCICLO,
                    CDSERVFILI
                FROM
                    SERVCARDCICLO 
                WHERE
                    CDFILIAL = :CDFILIAL AND
                    DTINICICLO <= :DTINICICLO
                GROUP BY
                    CDSERVFILI";
        $params = array(
            "CDFILIAL" => $row["CDFILIAL"],
            "DTINICICLO" => $row["DTINICICLO"]
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function getMaxDiffCiclo($row) {
        $query = "SELECT
                    COUNT(1) AS MAXDIF
                FROM
                    CARDADIACICLO
                WHERE
                    CDCARDCICLO =:CDCARDCICLO AND
                    CDPADCICLO =:CDPADCICLO AND
                    NRCARDCICLO >=:NRCARDCICLODEST";
        $params = array(
            "CDCARDCICLO" => $row["CDCARDCICLO"],
            "CDPADCICLO" => $row["CDPADCICLO"],
            "NRCARDCICLODEST" => $row["NRCARDCICLODEST"]
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function getPratoImportacao($row) {
        $query = "SELECT
                    CDCARDCICLO,
                    CDFILAUXPRAT,
                    CDPADCICLO,
                    CDPRATO,
                    CDTIPOPRAT,
                    NRCARDCICLO,
                    NRSEQCARDCICLO,
                    100 AS VRPECONSCARDCICLO
                FROM
                    COMPCARDCICLO
                WHERE
                    CDCARDCICLO =:CDCARDCICLO AND
                    CDPADCICLO =:CDPADCICLO AND
                    CDTIPOPRAT =:CDTIPOPRAT AND
                    NRSEQCARDCICLO =:NRSEQCARDCICLO AND
                    NRCARDCICLO =:NRCARDCICLO";
        $params = array(
            "CDCARDCICLO" => $row['CDCARDCICLO'],
            "CDPADCICLO" => $row['CDPADCICLO'],
            "CDTIPOPRAT" => $row['CDTIPOPRAT'],
            "NRSEQCARDCICLO" => $row['NRSEQCARDCICLO'],
            "NRCARDCICLO" => $row['NRCARDCICLO']
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function getPratoCicloCardapioDia($row) {
        $query = "SELECT
                    CDCARDCICLO
                FROM
                    COMPCARDCICLO
                WHERE
                    CDCARDCICLO =:CDCARDCICLO AND
                    CDPADCICLO =:CDPADCICLO AND
                    NRCARDCICLO =:NRCARDCICLO AND
                    CDTIPOPRAT =:CDTIPOPRAT AND
                    NRSEQCARDCICLO =:NRSEQCARDCICLO";
        $params = array(
            "CDCARDCICLO" => $row['CDCARDCICLO'],
            "CDPADCICLO" => $row['CDPADCICLO'],
            "NRCARDCICLO" => $row['NRCARDCICLO'],
            "CDTIPOPRAT" => $row['CDTIPOPRAT'],
            "NRSEQCARDCICLO" => $row['NRSEQCARDCICLO']
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function getPratosCiclo($row) {
        $query = "SELECT 
                    CD.CDCARDCICLO,
                    CF.CDPADCICLO,
                    LPAD(TO_CHAR(CD.NRCARDCICLO),3,'0') AS NRCARDCICLO,
                    LPAD(TO_CHAR(CF.NRORDCNFCICLO),3,'0') || TP.CDTIPOPRAT || TRIM(TP.NMTIPOPRAT) || DECODE(CF.DSCOMPTPCICLO, '', '', ' (' || CF.DSCOMPTPCICLO || ')' || DECODE(NVL(CF.IDOPCARDCICLO, 'N'), 'N', '', ' (Opção)')) AS NMTIPOPRATDELPHI,
                    CD.NRDIASEMCICLO,
                    CC.NRSEQCARDCICLO,
                    CF.NRSEQCNFCICLO,
                    CF.NRORDCNFCICLO,
                    CF.DSCOMPTPCICLO,
                    CF.IDOPCARDCICLO,
                    CC.CDTIPOPRAT,
                    TP.NMTIPOPRAT,
                    CC.CDFILAUXPRAT,
                    CC.CDPRATO,
                    PT.NMPRATO,
                    CC.VRPECONSCARDCICLO,
                    CC.VRPECONSCARDCICLO || '% ' || PT.NMPRATO AS LABEL
                FROM
                    PRATO PT,
                    TIPOPRAT TP,
                    CNFCARDCICLO CF,
                    COMPCARDCICLO CC,
                    CARDADIACICLO CD
                WHERE
                    CD.CDCARDCICLO = :CDCARDCICLO AND
                    CF.CDPADCICLO = :CDPADCICLO AND
                    CC.CDCARDCICLO = CD.CDCARDCICLO AND
                    CC.CDPADCICLO = CD.CDPADCICLO AND
                    CC.NRCARDCICLO = CD.NRCARDCICLO AND
                    TP.CDTIPOPRAT = CC.CDTIPOPRAT AND
                    PT.CDPRATO = CC.CDPRATO AND
                    PT.CDFILAUXPRAT = CC.CDFILAUXPRAT AND
                    CF.CDCARDCICLO = CC.CDCARDCICLO AND
                    CF.CDPADCICLO = CC.CDPADCICLO AND
                    CF.NRSEQCNFCICLO = CC.NRSEQCARDCICLO AND
                    CF.CDTIPOPRAT = CC.CDTIPOPRAT
                ORDER BY
                    CC.NRCARDCICLO,
                    CF.NRORDCNFCICLO";
        $params = array(
            "CDCARDCICLO" => $row["CDCARDCICLO"],
            "CDPADCICLO" => $row["CDPADCICLO"]
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function getPratosCopiar($row) {
        $query = "SELECT
                    CA.NRCARDCICLO,
                    CA.NRDIASEMCICLO,
                    (
                        SELECT
                            COUNT(1)
                        FROM
                            COMPCARDCICLO CC
                        WHERE
                            CC.CDCARDCICLO = CA.CDCARDCICLO AND
                            CC.CDPADCICLO = CA.CDPADCICLO AND
                            CC.NRCARDCICLO = CA.NRCARDCICLO AND
                            CC.CDTIPOPRAT =:CDTIPOPRAT AND
                            CC.NRSEQCARDCICLO =:NRSEQCARDCICLO
                    ) AS TEM_PRATO
                FROM
                    CARDADIACICLO CA
                WHERE
                    CA.CDCARDCICLO =:CDCARDCICLO AND
                    CA.CDPADCICLO =:CDPADCICLO AND
                    (
                        (
                            :NRCARDCICLOINI IS NULL AND
                            :NRCARDCICLOFIN IS NULL
                        ) OR (
                            :NRCARDCICLOINI IS NULL AND
                            CA.NRCARDCICLO <=:NRCARDCICLOFIN
                        ) OR (
                            :NRCARDCICLOFIN IS NULL AND
                            CA.NRCARDCICLO >=:NRCARDCICLOINI
                        ) OR (
                            CA.NRCARDCICLO BETWEEN :NRCARDCICLOINI AND :NRCARDCICLOFIN
                        )
                    ) AND (
                        (
                            :DIASEMANA IS NULL
                        ) OR (
                            INSTR(
                                :DIASEMANA,
                                TO_CHAR(CA.NRDIASEMCICLO+1)
                            ) <> 0
                        )
                    ) AND (
                        :SOBREPORPRATOS = 'S' OR
                        (
                            :SOBREPORPRATOS = 'N' AND
                            (
                                SELECT
                                    COUNT(1)
                                FROM
                                    COMPCARDCICLO CC
                                WHERE
                                    CC.CDCARDCICLO = CA.CDCARDCICLO AND
                                    CC.CDPADCICLO = CA.CDPADCICLO AND
                                    CC.NRCARDCICLO = CA.NRCARDCICLO AND
                                    CC.CDTIPOPRAT =:CDTIPOPRAT AND
                                    CC.NRSEQCARDCICLO =:NRSEQCARDCICLO
                            ) <> 1
                        )
                    )";
        $params = array(
            "CDTIPOPRAT" => $row["CDTIPOPRAT"],
            "NRSEQCARDCICLO" => $row["NRSEQCARDCICLO"],
            "CDCARDCICLO" => $row["CDCARDCICLO"],
            "CDPADCICLO" => $row["CDPADCICLO"],
            "NRCARDCICLOINI" => $row["NRCARDCICLOINI"],
            "NRCARDCICLOFIN" => $row["NRCARDCICLOFIN"],
            "DIASEMANA" => $row["DIASEMANA"],
            "SOBREPORPRATOS" => $row["SOBREPORPRATOS"]
        );
         
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function getPratosCopiarComensais($row) {
        $query = "SELECT
                    CA.NRCARDCICLO,
                    CA.NRDIASEMCICLO
                FROM
                    CARDADIACICLO CA
                WHERE
                    CA.CDCARDCICLO =:CDCARDCICLO AND
                    CA.CDPADCICLO =:CDPADCICLO AND
                    (
                        (
                            :NRCARDCICLOINI IS NULL AND
                            :NRCARDCICLOFIN IS NULL
                        ) OR (
                            :NRCARDCICLOINI IS NULL AND
                            CA.NRCARDCICLO <=:NRCARDCICLOFIN
                        ) OR (
                            :NRCARDCICLOFIN IS NULL AND
                            CA.NRCARDCICLO >=:NRCARDCICLOINI
                        ) OR (
                            CA.NRCARDCICLO BETWEEN :NRCARDCICLOINI AND :NRCARDCICLOFIN
                        )
                    ) AND (
                        SELECT
                            COUNT(1)
                        FROM
                            COMPCARDCICLO CC
                        WHERE
                            CC.CDCARDCICLO = CA.CDCARDCICLO AND
                            CC.CDPADCICLO = CA.CDPADCICLO AND
                            CC.NRCARDCICLO = CA.NRCARDCICLO AND
                            CC.CDTIPOPRAT =:CDTIPOPRAT AND
                            CC.NRSEQCARDCICLO =:NRSEQCARDCICLO
                    ) = 1";
        $params = array(
            "CDCARDCICLO" => $row["CDCARDCICLO"],
            "CDPADCICLO" => $row["CDPADCICLO"],
            "NRCARDCICLOINI" => $row["NRCARDCICLOINI"],
            "NRCARDCICLOFIN" => $row["NRCARDCICLOFIN"],
            "CDTIPOPRAT" => $row["CDTIPOPRAT"],
            "NRSEQCARDCICLO" => $row["NRSEQCARDCICLO"]
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function getTipoPratoCorrespondente($row) {
        $query = "SELECT
                    CDTIPOPRAT,
                    NRSEQCNFCICLO,
                    CDTIPOPRATDEST,
                    NRSEQCNFCICLODEST,
                    RN
                FROM
                    (
                        SELECT
                            ORIG.CDTIPOPRAT,
                            ORIG.NRSEQCNFCICLO,
                            DEST.CDTIPOPRAT AS CDTIPOPRATDEST,
                            DEST.NRSEQCNFCICLO AS NRSEQCNFCICLODEST,
                            ROW_NUMBER() OVER(PARTITION BY
                                ORIG.CDTIPOPRAT,
                                ORIG.NRSEQCNFCICLO,
                                DEST.CDTIPOPRAT,
                                DEST.NRSEQCNFCICLO
                                ORDER BY
                                    ORIG.CDTIPOPRAT,
                                    ORIG.NRORDCNFCICLO,
                                    DEST.CDTIPOPRAT,
                                    DEST.NRORDCNFCICLO
                            ) RN
                        FROM
                            CNFCARDCICLO ORIG
                            INNER JOIN CNFCARDCICLO DEST ON DEST.CDTIPOPRAT = ORIG.CDTIPOPRAT
                        WHERE
                            ORIG.CDCARDCICLO =:CDCARDCICLOORIG AND
                            ORIG.CDPADCICLO =:CDPADCICLOORIG AND
                            DEST.CDCARDCICLO =:CDCARDCICLODEST AND
                            DEST.CDPADCICLO =:CDPADCICLODEST
                    )
                WHERE
                    RN = 1";
        $params = array(
            "CDCARDCICLOORIG" => $row["CDCARDCICLO"],
            "CDPADCICLOORIG" => $row["CDPADCICLO"],
            "CDCARDCICLODEST" => $row["CDCARDCICLODEST"],
            "CDPADCICLODEST" => $row["CDPADCICLODEST"]
        );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
    
    public function insertLogIntoLista($row) {
        $query = "INSERT INTO LISTA (
                    NRLISTA,
                    CDLISTA
                )
                VALUES (
                    :NRLISTA,
                    :CDLISTA
                )";
        $params = array(
            "NRLISTA" => $row["NRLISTA"],
            "CDLISTA" => $row["CDLISTA"]
        );
        $sql = $this->entityManager->getConnection()->prepare($query);
        $sql->execute($params);
    }
    
    public function insertPrato($row) {
        $query = "INSERT INTO COMPCARDCICLO (
                    CDCARDCICLO,
                    CDPADCICLO,
                    NRCARDCICLO,
                    NRSEQCARDCICLO,
                    CDTIPOPRAT,
                    CDPRATO,
                    CDFILAUXPRAT,
                    VRPECONSCARDCICLO
                )
                VALUES (
                    :CDCARDCICLO,
                    :CDPADCICLO,
                    :NRCARDCICLO,
                    :NRSEQCARDCICLO,
                    :CDTIPOPRAT,
                    :CDPRATO,
                    :CDFILAUXPRAT,
                    :VRPECONSCARDCICLO
                )";
        $params = array(
            "CDCARDCICLO" => $row["CDCARDCICLO"],
            "CDPADCICLO" => $row["CDPADCICLO"],
            "NRCARDCICLO" => $row["NRCARDCICLO"],
            "NRSEQCARDCICLO" => $row["NRSEQCARDCICLO"],
            "CDTIPOPRAT" => $row["CDTIPOPRAT"],
            "CDPRATO" => $row["CDPRATO"],
            "CDFILAUXPRAT" => $row["CDFILAUXPRAT"],
            "VRPECONSCARDCICLO" => $row["VRPECONSCARDCICLO"]
        );
        $sql = $this->entityManager->getConnection()->prepare($query);
        $sql->execute($params);
    }
    
    public function insertPratoFromCardapio($row) {
        $query = "INSERT INTO COMPCARDCICLO (
                    CDCARDCICLO,
                    CDPADCICLO,
                    NRCARDCICLO,
                    NRSEQCARDCICLO,
                    CDTIPOPRAT,
                    CDPRATO,
                    CDFILAUXPRAT,
                    VRPECONSCARDCICLO
                ) ( SELECT
                        :CDCARDCICLO,
                        :CDPADCICLO,
                        :NRCARDCICLO,
                        :NRSEQCARDCICLO,
                        :CDTIPOPRAT,
                        CP.CDPRATO,
                        CP.CDFILAUXPRAT,
                        100
                    FROM
                        COMPCARD CP,
                        CARDADIA CC,
                        CNFCAMES CN
                    WHERE
                        CC.CDFILIAL = :CDFILIAL AND
                        CP.CDFILIAL = CC.CDFILIAL AND
                        CC.CDSERVFILI = :CDSERVFILI AND
                        CC.DTCARDAPIO = :DTCARDAPIO AND
                        CP.NRCARDAPIO = CC.NRCARDAPIO AND
                        CP.CDTIPOPRAT = :CDTIPOPRATCAR AND
                        CP.NRSEQPRATCAR = CN.NRSEQCNFMES AND
                        CN.CDFILIAL = CC.CDFILIAL AND
                        CN.CDSERVFILI = CC.CDSERVFILI AND
                        CN.DTREFECNFMES = ( '01' || SUBSTR(
                            :DTCARDAPIO,
                            3
                        ) ) AND
                        NRORDCNFMES = :NRSEQPRATCAR AND
                        CP.CDFILAUXPRAT = 'P'
                )";
        $params = array (
            "NRSEQCARDCICLO" => $row['NRSEQCARDCICLO'],
            "DTCARDAPIO" => $row['DTCARDAPIO'],
            "CDCARDCICLO" => $row['CDCARDCICLO'],
            "CDTIPOPRAT" => $row['CDTIPOPRAT'],
            "CDSERVFILI" => $row['CDSERVFILI'],
            "NRCARDCICLO" => $row['NRCARDCICLO'],
            "NRSEQPRATCAR" => $row['NRSEQPRATCAR'],
            "CDPADCICLO" => $row['CDPADCICLO'],
            "CDTIPOPRATCAR" => $row['CDTIPOPRATCAR'],
            "CDFILIAL" => $row['CDFILIAL']
        );
        $sql = $this->entityManager->getConnection()->prepare($query);
        $sql->execute($params);
    }
    
    public function updateComensais($row) {
        $query = "UPDATE
                    COMPCARDCICLO
                SET
                    VRPECONSCARDCICLO = :VRPECONSCARDCICLO
                WHERE 
                    CDCARDCICLO = :CDCARDCICLO AND
                    CDPADCICLO = :CDPADCICLO AND
                    NRCARDCICLO = :NRCARDCICLO AND
                    NRSEQCARDCICLO = :NRSEQCARDCICLO";
        $params = array(
            "VRPECONSCARDCICLO" => $row["VRPECONSCARDCICLO"],
            "CDCARDCICLO" => $row["CDCARDCICLO"],
            "CDPADCICLO" => $row["CDPADCICLO"],
            "NRCARDCICLO" => $row["NRCARDCICLO"],
            "NRSEQCARDCICLO" => $row["NRSEQCARDCICLO"]
        );
        $sql = $this->entityManager->getConnection()->prepare($query);
        $sql->execute($params);
    }
    
    public function updatePrato($row) {
        $query = "UPDATE
                    COMPCARDCICLO
                SET 
                    CDTIPOPRAT = :CDTIPOPRAT,
                    CDPRATO = :CDPRATO,
                    CDFILAUXPRAT = :CDFILAUXPRAT,
                    VRPECONSCARDCICLO = :VRPECONSCARDCICLO
                WHERE 
                    CDCARDCICLO = :CDCARDCICLO AND
                    CDPADCICLO = :CDPADCICLO AND
                    NRCARDCICLO = :NRCARDCICLO AND
                    NRSEQCARDCICLO = :NRSEQCARDCICLO";
        $params = array(
            "CDTIPOPRAT" => $row["CDTIPOPRAT"],
            "CDPRATO" => $row["CDPRATO"],
            "CDFILAUXPRAT" => $row["CDFILAUXPRAT"],
            "VRPECONSCARDCICLO" => $row["VRPECONSCARDCICLO"],
            "CDCARDCICLO" => $row["CDCARDCICLO"],
            "CDPADCICLO" => $row["CDPADCICLO"],
            "NRCARDCICLO" => $row["NRCARDCICLO"],
            "NRSEQCARDCICLO" => $row["NRSEQCARDCICLO"]
        );
        $sql = $this->entityManager->getConnection()->prepare($query);
        $sql->execute($params);
    }
}

